@@ -1,7 +1,5 @@
 """
-Type annotations for iot-data service client.
-
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html)
+Main interface for iot-data service client
 
 Usage::
 
@@ -50,8 +48,7 @@ class Exceptions:
 
 class IoTDataPlaneClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html)
+    [IoTDataPlane.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/iot-data.html#IoTDataPlane.Client)
     """
 
     meta: ClientMeta
@@ -59,16 +56,14 @@ class IoTDataPlaneClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#can-paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
         """
 
     def delete_thing_shadow(
         self, thingName: str, shadowName: str = None
     ) -> DeleteThingShadowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#delete-thing-shadow)
+        [Client.delete_thing_shadow documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
         """
 
     def generate_presigned_url(
@@ -79,36 +74,31 @@ class IoTDataPlaneClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#generate-presigned-url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
         """
 
     def get_thing_shadow(
         self, thingName: str, shadowName: str = None
     ) -> GetThingShadowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#get-thing-shadow)
+        [Client.get_thing_shadow documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
         """
 
     def list_named_shadows_for_thing(
         self, thingName: str, nextToken: str = None, pageSize: int = None
     ) -> ListNamedShadowsForThingResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#list-named-shadows-for-thing)
+        [Client.list_named_shadows_for_thing documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
         """
 
     def publish(self, topic: str, qos: int = None, payload: Union[bytes, IO[bytes]] = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.publish)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#publish)
+        [Client.publish documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/iot-data.html#IoTDataPlane.Client.publish)
         """
 
     def update_thing_shadow(
         self, thingName: str, payload: Union[bytes, IO[bytes]], shadowName: str = None
     ) -> UpdateThingShadowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#update-thing-shadow)
+        [Client.update_thing_shadow documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
         """
